@@ -15,11 +15,11 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/kubectl/pkg/scheme"
+	"k8s.io/client-go/kubernetes/scheme"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 
-	manifestworkv1 "github.com/open-cluster-management/api/work/v1"
 	agentv1 "github.com/stolostron/klusterlet-addon-controller/pkg/apis/agent/v1"
+	manifestworkv1 "open-cluster-management.io/api/work/v1"
 )
 
 func TestMain(m *testing.M) {
@@ -39,11 +39,11 @@ func setup() error {
 			Kind:       "ConfigMap",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      "test-configmap-2.3.9",
+			Name:      "test-configmap-2.4.2",
 			Namespace: "test-namespace",
 			Labels: map[string]string{
 				"ocm-configmap-type":  "image-manifest",
-				"ocm-release-version": "2.3.9",
+				"ocm-release-version": "2.4.2",
 			},
 		},
 		Data: map[string]string{
@@ -87,13 +87,18 @@ func Test_createManifestWorkComponentOperator(t *testing.T) {
 			Namespace: "test-managedcluster",
 		},
 		Spec: agentv1.KlusterletAddonConfigSpec{
-			ApplicationManagerConfig: agentv1.KlusterletAddonConfigApplicationManagerSpec{
+			ApplicationManagerConfig: agentv1.KlusterletAddonAgentConfigSpec{
 				Enabled: true,
 			},
-			ImagePullSecret: "test-managedcluster",
 		},
 	}
 
+	testAddonAgentConfig := &agentv1.AddonAgentConfig{
+		KlusterletAddonConfig:    testKlusterletAddonConfig,
+		ClusterName:              "test-managedcluster",
+		ImagePullSecret:          "test-managedcluster",
+		ImagePullSecretNamespace: "test-managedcluster",
+	}
 	testSecret := &corev1.Secret{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: corev1.SchemeGroupVersion.String(),
@@ -124,8 +129,8 @@ func Test_createManifestWorkComponentOperator(t *testing.T) {
 	}
 
 	type args struct {
-		r                  *ReconcileKlusterletAddon
-		klusterletaddoncfg *agentv1.KlusterletAddonConfig
+		r                *ReconcileKlusterletAddon
+		addonAgentConfig *agentv1.AddonAgentConfig
 	}
 
 	tests := []struct {
@@ -142,7 +147,7 @@ func Test_createManifestWorkComponentOperator(t *testing.T) {
 					}...),
 					scheme: testscheme,
 				},
-				klusterletaddoncfg: testKlusterletAddonConfig,
+				addonAgentConfig: testAddonAgentConfig,
 			},
 			wantErr: false,
 		},
@@ -155,7 +160,7 @@ func Test_createManifestWorkComponentOperator(t *testing.T) {
 					}...),
 					scheme: testscheme,
 				},
-				klusterletaddoncfg: testKlusterletAddonConfig,
+				addonAgentConfig: testAddonAgentConfig,
 			},
 			wantErr: true,
 		},
@@ -163,7 +168,7 @@ func Test_createManifestWorkComponentOperator(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			err := createManifestWorkComponentOperator(tt.args.klusterletaddoncfg, tt.args.r)
+			err := createManifestWorkComponentOperator(tt.args.addonAgentConfig, tt.args.r)
 			if (err != nil) != tt.wantErr {
 				t.Errorf("createManifestWorkComponentOperator() error = %v, wantErr %v", err, tt.wantErr)
 				return
